@@ -13,3 +13,5 @@ CANCEL_ALL = "/cancel-all"
 MID_POINT = "/midpoint"
 PRICE = "/price"
 GET_LAST_TRADE_PRICE = "/last-trade-price"
+GET_TRADE_NOTIFICATIONS = "/trade-notifications"
+DROP_TRADE_NOTIFICATIONS = "/drop-trade-notifications"
