@@ -1,7 +1,11 @@
 from unittest import TestCase
-from py_clob_client.clob_types import FilterParams
+from py_clob_client.clob_types import FilterParams, TradeNotificationParams
 
-from py_clob_client.http_helpers.helpers import build_query_params, add_query_params
+from py_clob_client.http_helpers.helpers import (
+    build_query_params,
+    add_query_params,
+    add_trade_notifications_query_params,
+)
 
 
 class TestHelpers(TestCase):
@@ -25,3 +29,11 @@ class TestHelpers(TestCase):
         self.assertEqual(
             url, "http://tracker?market=10000&limit=250&after=1450000&before=1460000"
         )
+
+    def test_add_trade_notifications_query_params(self):
+        url = add_trade_notifications_query_params(
+            "http://tracker",
+            TradeNotificationParams(index=12345),
+        )
+        self.assertIsNotNone(url)
+        self.assertEqual(url, "http://tracker?index=12345")
